@@ -1,5 +1,5 @@
 package Treex::Block::Read::Sentences;
-$Treex::Block::Read::Sentences::VERSION = '2.20151216';
+$Treex::Block::Read::Sentences::VERSION = '2.20160629';
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Block::Read::BaseTextReader';
@@ -13,7 +13,7 @@ sub next_document {
 
     my $document = $self->new_document();
     foreach my $sentence ( split /\n/, $text ) {
-        next if ($sentence eq '' and $self->skip_empty);
+        next if ($sentence =~ /^\s*$/ and $self->skip_empty);
         my $bundle = $document->create_bundle();
         my $zone = $bundle->create_zone( $self->language, $self->selector );
         $zone->set_sentence($sentence);
@@ -36,7 +36,7 @@ Treex::Block::Read::Sentences
 
 =head1 VERSION
 
-version 2.20151216
+version 2.20160629
 
 =head1 SYNOPSIS
 
