@@ -1,5 +1,5 @@
 package Treex::Core::Node::Ordered;
-$Treex::Core::Node::Ordered::VERSION = '2.20151216';
+$Treex::Core::Node::Ordered::VERSION = '2.20160629';
 use Moose::Role;
 
 # with Moose >= 2.00, this must be present also in roles
@@ -88,8 +88,12 @@ sub _normalize_node_ordering {
     log_fatal 'Incorrect number of arguments' if @_ != 1;
     my $self = shift;
     log_fatal('Ordering normalization can be applied only on root nodes!') if $self->get_parent();
+    # Do not use add_self => 1. Unshift myself as the first element instead.
+    # Otherwise normalization will not work as expected if the current ord of the root is nonzero and/or a non-root node has zero.
+    my @nodes = $self->get_descendants( { ordered => 1 } );
+    unshift(@nodes, $self);
     my $new_ord = 0;
-    foreach my $node ( $self->get_descendants( { ordered => 1, add_self => 1 } ) ) {
+    foreach my $node (@nodes) {
         $node->_set_ord($new_ord);
         $new_ord++
     }
@@ -323,7 +327,7 @@ Treex::Core::Node::Ordered
 
 =head1 VERSION
 
-version 2.20151216
+version 2.20160629
 
 =head1 DESCRIPTION
 
