@@ -1,5 +1,5 @@
 package Treex::Core::Node::T;
-$Treex::Core::Node::T::VERSION = '2.20151216';
+$Treex::Core::Node::T::VERSION = '2.20160629';
 use namespace::autoclean;
 
 use Moose;
@@ -159,7 +159,7 @@ sub get_anodes {
     return $self->_process_switches( $arg_ref, @nodes );
 }
 
-#------------ coreference nodes -------------------
+#------------ coreference and bridging nodes -------------------
 
 sub get_coref_nodes {
     my ( $self, $arg_ref ) = @_;
@@ -274,6 +274,24 @@ sub update_coref_nodes {
     return;
 }
 
+sub get_bridging_nodes {
+    my ($self, $arg_ref) = @_;
+    my $bridging = $self->get_attr('bridging') // [];
+    my $doc = $self->get_document;
+    my @nodes = map {$doc->get_node_by_id($_->{'target_node.rf'})} @$bridging; 
+    my @types = map {$_->{'type'}} @$bridging;
+    return (\@nodes, \@types);
+}
+
+sub add_bridging_node {
+    my ( $self, $node, $type ) = @_;
+    my $links_rf = $self->get_attr('bridging');
+    my %new_link = ( 'target_node.rf' => $node->id, 'type' => $type // ''); #/ so we have no undefs
+    push( @$links_rf, \%new_link );
+    $self->set_attr( 'bridging', $links_rf );
+    return;
+}
+
 # ----------- complement nodes -------------
 
 sub get_compl_nodes {
@@ -386,7 +404,7 @@ Treex::Core::Node::T
 
 =head1 VERSION
 
-version 2.20151216
+version 2.20160629
 
 =head1 DESCRIPTION
 
@@ -459,6 +477,15 @@ Remove the specified nodes from C<coref_gram.rf> or C<coref_text.rf> (if they ar
 
 Remove all invalid coreferences from C<coref_gram.rf> and C<coref_text.rf>.
 
+=item $node->get_bridging_nodes()
+
+Access the nodes referred from the current node by bridging anaphora (in C<bridging> attribute).
+The method returns references to two lists of the equal length: the referred nodes and the types of bridging relations.
+
+=item $node->add_bridging_node($node, $type)
+
+Add bridging anaphora to C<$node> of type C<$type> (to C<bridging>).
+
 =back
 
 =head2 Access to source language t-layer (in MT)
