@@ -1,5 +1,5 @@
 package Treex::Core::TredView::Labels;
-$Treex::Core::TredView::Labels::VERSION = '2.20151216';
+$Treex::Core::TredView::Labels::VERSION = '2.20160629';
 use Moose;
 use Treex::Core::TredView::Common;
 use Treex::Core::Log;
@@ -219,7 +219,10 @@ sub _anode_labels {
         {
             $parent = $parent->parent;
         }
-        if ( $parent->afun =~ m/^(Ap)os|(Co)ord/ ) {
+        my $pafun = $parent->afun();
+        $pafun = $parent->deprel() if(!defined($pafun));
+        $pafun = '' if(!defined($pafun));
+        if ( $pafun =~ m/^(Ap)os|(Co)ord/ ) {
             $line2 .= '_' . $self->_colors->get( 'member', 1 ) . ( $1 ? $1 : $2 );
         }
     }
@@ -283,7 +286,7 @@ sub _tnode_labels {
         $line1 .= $self->_colors->get( 'sentmod', 1 ) . '.' . $node->sentmod;
     }
 
-    foreach my $type ( 'compl', 'coref_text', 'coref_gram' ) {
+    foreach my $type ( 'compl', 'coref_text', 'coref_gram', 'bridging' ) {
         if ( defined $node->{ $type . '.rf' } ) {
             foreach my $ref ( TredMacro::ListV( $node->{ $type . '.rf' } ) ) {
                 my $ref_node = $self->_treex_doc->get_node_by_id($ref);
@@ -292,6 +295,14 @@ sub _tnode_labels {
                 }
             }
         }
+        elsif ( defined $node->{ $type } ) {
+           foreach my $ref ( map {$_->{ 'target_node.rf' }} TredMacro::ListV( $node->{ $type } ) ) {
+                my $ref_node = $self->_treex_doc->get_node_by_id($ref);
+                if ( $node->get_bundle->get_position() != $ref_node->get_bundle->get_position() ) {
+                    $line1 .= ' ' . $self->_colors->get( $type, 1 ) . $ref_node->{t_lemma};
+                }
+           }
+       }
     }
 
     my $line2 = $node->{functor};
@@ -377,7 +388,7 @@ Treex::Core::TredView::Labels - Labels of tree nodes in Tred
 
 =head1 VERSION
 
-version 2.20151216
+version 2.20160629
 
 =head1 DESCRIPTION
 
